package com.diagbot.aop;

import com.diagbot.annotation.CdssLog;
import com.diagbot.entity.TranLog;
import com.diagbot.rabbit.MySender;
import com.diagbot.util.CdssLogUtil;
import com.diagbot.util.DateUtil;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

import java.lang.reflect.Method;
import java.util.Date;

/**
 * @Description: 日志记录切面
 * @author: gaodm
 * @time: 2021/10/20 9:58
 */
@Aspect
@Component
@ConditionalOnProperty(prefix = "cdssLog", value = { "enable" }, havingValue = "true")
@Slf4j
public class CdssLogAspect {

    @Autowired
    MySender mySender;

    //切所有Controller
    @Pointcut("execution(* com.diagbot.web..*.*(..)) && @annotation(com.diagbot.annotation.CdssLog)")
    public void pointcutController() {
    }

    @Around("pointcutController()")
    public Object cdssLogIntercept(ProceedingJoinPoint joinPoint) throws Throwable {
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();
        Method method = signature.getMethod();
        //获取方法参数
        Object[] args = joinPoint.getArgs();
        //请求的参数
        TranLog tanLog = CdssLogUtil.tranLogReqAspect(joinPoint);
        Date now = DateUtil.now();
        tanLog.setGmtCreate(now);
        tanLog.setGmtModified(now);
        tanLog.setSceneName(method.getAnnotation(CdssLog.class).value());
        long start = System.currentTimeMillis();
        tanLog.setGmtReq(DateUtil.now());
        Object proceed = joinPoint.proceed(args);
        //执行方法后获取出参
        tanLog = CdssLogUtil.tranLogRespAspect(proceed, tanLog, start, joinPoint);

        //异步记录日志
        mySender.outputCdssLogSend(tanLog);
        return proceed;
    }

    @AfterThrowing(pointcut = "pointcutController()", throwing = "ex")
    public void cdssLogInterceptThrow(JoinPoint joinPoint, Throwable ex) {
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();
        Method method = signature.getMethod();
        TranLog tanLog = new TranLog();
        Date now = DateUtil.now();
        tanLog.setGmtCreate(now);
        tanLog.setGmtModified(now);
        tanLog.setSceneName(method.getAnnotation(CdssLog.class).value());
        long start = System.currentTimeMillis();
        tanLog.setGmtReq(DateUtil.now());
        tanLog = CdssLogUtil.tranLogRespAspectThrow(joinPoint, tanLog, start, ex);

        //保存日志
        mySender.outputCdssLogSend(tanLog);
    }
}
