package com.diagbot.client.hystrix;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.client.CdssCoreClient;
import com.diagbot.dto.ConceptDetailDTO;
import com.diagbot.dto.ConceptScaleDTO;
import com.diagbot.dto.DictionaryInfoDTO;
import com.diagbot.dto.GetAllForRelationDTO;
import com.diagbot.dto.IndexBatchDTO;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.KlConceptStaticDTO;
import com.diagbot.dto.KlRuleByIdParDTO;
import com.diagbot.dto.KlRuleInfoDTO;
import com.diagbot.dto.KllisDetailDTO;
import com.diagbot.dto.PushDTO;
import com.diagbot.dto.PushPlanDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.RetrievalDTO;
import com.diagbot.dto.StaticKnowledgeDTO;
import com.diagbot.dto.StaticKnowledgeIndexDTO;
import com.diagbot.dto.StaticKnowledgeIndexPageDTO;
import com.diagbot.dto.TermConceptDTO;
import com.diagbot.entity.KlRuleMenuWrapper;
import com.diagbot.vo.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @Description: 病历质控客户端（请求失败熔断）
 * @author: gaodm
 * @time: 2020/7/28 9:29
 */
@Component
@Slf4j
public class CdssCoreHystrix implements CdssCoreClient {

    @Override
    public RespDTO<IndicationDTO> indication(@Valid @RequestBody IndicationPushVO indicationPushVO) {
        log.error("【hystrix】调用{}异常", "indication");
        return null;
    }

    @Override
    public RespDTO<PushDTO> push(@RequestBody @Valid PushVO pushVo) {
        log.error("【hystrix】调用{}异常", "push");
        return null;
    }

    /**
     * 推送持续检验检查计划
     */
    @Override
    public RespDTO<PushPlanDTO> pushPlan(@RequestBody PushPlanVO pushPlanVO) {
        log.error("【hystrix】调用{}异常", "pushPlan");
        return null;
    }

    /**
     * 化验大项、化验小项、辅检、诊断、药品、手术等检索
     *
     * @param retrievalVO
     * @return
     */
    @Override
    public RespDTO<RetrievalDTO> index(@RequestBody @Valid RetrievalVO retrievalVO) {
        log.error("【hystrix】调用{}异常", "index");
        return null;
    }


    /**
     * 国药准字匹配
     *
     * @param indexByApprovalVO
     * @return
     */
    @Override
    public RespDTO<List<IndexBatchDTO>> indexByApproval(@Valid @RequestBody IndexByApprovalVO indexByApprovalVO) {
        log.error("【hystrix】调用{}异常", "indexByApproval");
        return null;
    }

    /**
     * 静态知识检索
     *
     * @param staticKnowledgeIndexVO
     * @return
     */
    @Override
    public RespDTO<List<StaticKnowledgeIndexDTO>> staticKnowledgeIndex(@RequestBody @Valid StaticKnowledgeIndexVO staticKnowledgeIndexVO) {
        log.error("【hystrix】调用{}异常", "staticKnowledgeIndex");
        return null;
    }

    /**
     * 术语关联医学术语检索
     *
     * @param filterVO
     * @return
     */
    @Override
    public RespDTO<List<IndexBatchDTO>> filter(@Valid @RequestBody FilterVO filterVO) {
        log.error("【hystrix】调用{}异常", "filter");
        return null;
    }

    /**
     * 更新是否有静态知识状态
     *
     * @param hasStaticKnowledgeVO
     * @return
     */
    @Override
    public RespDTO<Boolean> updateHasInfoStatus(@Valid @RequestBody HasStaticKnowledgeVO hasStaticKnowledgeVO) {
        log.error("【hystrix】调用{}异常", "updateHasInfoStatus");
        return null;
    }

    /**
     * 术语批量校验
     *
     * @param conceptVO
     * @return
     */
    @Override
    public RespDTO<List<IndexBatchDTO>> getConceptNames(@Valid @RequestBody ConceptVO conceptVO) {
        log.error("【hystrix】调用{}异常", "getConceptNames");
        return null;
    }

    /**
     * 化验小项术语批量查询获取范围
     *
     * @param kllisDetailVO
     * @return
     */
    @Override
    public RespDTO<Map<String, KllisDetailDTO>> getLisDetaisByNames(@RequestBody KllisDetailVO kllisDetailVO) {
        log.error("【hystrix】调用{}异常", "getConceptNames");
        return null;
    }

    /**
     * 取上级静态知识
     *
     * @param staticKnowledgeNameVO
     * @return
     */
    @Override
    public RespDTO<StaticKnowledgeNameVO> getSuperName(@Valid @RequestBody StaticKnowledgeNameVO staticKnowledgeNameVO) {
        log.error("【hystrix】调用{}异常", "getSuperName");
        return null;
    }

    /**
     * 取上级静态知识（批量）
     *
     * @param staticKnowledgeNameVO
     * @return
     */
    @Override
    public RespDTO<List<StaticKnowledgeNameVO>> getSuperNameBatch(@Valid @RequestBody List<StaticKnowledgeNameVO> staticKnowledgeNameVO) {
        log.error("【hystrix】调用{}异常", "getSuperNameBatch");
        return null;
    }

    /**
     * 根据名称和类型获取静态知识内容
     *
     * @param scaleStaticAllVO
     * @return
     */
    @Override
    public RespDTO<StaticKnowledgeDTO> getStaticKnowledge(@Valid @RequestBody ScaleStaticAllVO scaleStaticAllVO) {
        log.error("【hystrix】调用{}异常", "getStaticKnowledge");
        return null;
    }

    /**
     * 分页查询
     *
     * @param klConceptStaticPageVO
     * @return
     */
    @Override
    public RespDTO<Page<KlConceptStaticDTO>> getPage(@Valid @RequestBody KlConceptStaticPageVO klConceptStaticPageVO) {
        log.error("【hystrix】调用{}异常", "getPage");
        return null;
    }

    /**
     * 静态知识检索（分页返回）
     *
     * @param staticKnowledgeIndexPageVO
     * @return
     */
    @Override
    public RespDTO<Page<StaticKnowledgeIndexPageDTO>> staticIndexPage(@Valid @RequestBody StaticKnowledgeIndexPageVO staticKnowledgeIndexPageVO) {
        log.error("【hystrix】调用{}异常", "staticIndexPage");
        return null;
    }

    /**
     * 保存静态知识
     *
     * @param klConceptStaticVO
     * @return
     */
    @Override
    public RespDTO<Boolean> saveOrUpdateRecord(@Valid @RequestBody KlConceptStaticVO klConceptStaticVO) {
        log.error("【hystrix】调用{}异常", "saveOrUpdateRecord");
        return null;
    }

    /**
     * 静态知识启用禁用
     *
     * @param changeStatusVO
     * @return
     */
    @Override
    public RespDTO<Boolean> changeStatus(@Valid @RequestBody ChangeStatusVO changeStatusVO) {
        log.error("【hystrix】调用{}异常", "changeStatus");
        return null;
    }

    /**
     * 根据id获取静态知识
     *
     * @param idVO
     * @return
     */
    @Override
    public RespDTO<KlConceptStaticDTO> getRecordById(@Valid @RequestBody IdVO idVO) {
        log.error("【hystrix】调用{}异常", "getRecordById");
        return null;
    }

    /**
     * 静态知识是否已存在
     *
     * @param klConceptStaticVO
     * @return
     */
    @Override
    public RespDTO<Boolean> isExist(@Valid @RequestBody KlConceptStaticVO klConceptStaticVO) {
        log.error("【hystrix】调用{}异常", "isExist");
        return null;
    }

    /**
     * 推理结果匹配静态知识
     *
     * @param getDetailVO
     * @return
     */
    @Override
    public RespDTO<Map<String, List<ConceptDetailDTO>>> getDetailByConcept(@Valid @RequestBody GetDetailVO getDetailVO) {
        log.error("【hystrix】调用{}异常", "getDetailByConcept");
        return null;
    }

    /**
     * 推理结果匹配量表
     *
     * @param getDetailVO
     * @return
     */
    @Override
    public RespDTO<Map<String, ConceptScaleDTO>> getScaleDetailByConcept(@RequestBody @Valid GetDetailVO getDetailVO) {
        log.error("【hystrix】调用{}异常", "getScaleDetailByConcept");
        return null;
    }

    @Override
    public RespDTO<List<KlRuleMenuWrapper>> getMenus(KlRuleMenuVO klRuleMenuVO) {
        log.error("【hystrix】调用{}异常", "getMenus");
        return null;
    }

    @Override
    public RespDTO<Page<KlRuleInfoDTO>> getKlRuleInfoPages(KlRuleInfoVO klRuleInfoVO) {
        log.error("【hystrix】调用{}异常", "getKlRuleInfoPages");
        return null;
    }

    @Override
    public RespDTO<KlRuleByIdParDTO> getByIdRuleInfoAll(@Valid KlRuleByIdVO klRuleByIdVO) {
        log.error("【hystrix】调用{}异常", "getByIdRuleInfoAll");
        return null;
    }

    @Override
    public RespDTO<Boolean> saveRuleInfoAll(@Valid KlRuleInfoSaveVO klRuleInfoSaveVO) {
        log.error("【hystrix】调用{}异常", "saveRuleInfoAll");
        return null;
    }

    @Override
    public RespDTO<Boolean> clearRuleInfoAll(@Valid KlRuleInfoClearVO klRuleInfoClearVO) {
        log.error("【hystrix】调用{}异常", "clearRuleInfoAll");
        return null;
    }

    @Override
    public RespDTO<Boolean> disableRuleInfos(@Valid KlRuleSatartOrdisaVO klRuleSatartOrdisaVO) {
        log.error("【hystrix】调用{}异常", "disableRuleInfos");
        return null;
    }

    @Override
    public RespDTO<Boolean> startRuleInfos(@Valid KlRuleSatartOrdisaVO klRuleSatartOrdisaVO) {
        log.error("【hystrix】调用{}异常", "startRuleInfos");
        return null;
    }

    @Override
    public RespDTO<Map<Long, List<DictionaryInfoDTO>>> getDictionaryAll() {
        log.error("【hystrix】调用{}异常", "getDictionaryAll");
        return null;
    }

    @Override
    public RespDTO<List<GetAllForRelationDTO>> searchConcept(@Valid SearchConceptVO searchConceptVO) {
        log.error("【hystrix】调用{}异常", "searchConcept");
        return null;
    }

    @Override
    public RespDTO<List<GetAllForRelationDTO>> addConceptClass(@Valid SearchConceptVO searchConceptVO) {
        log.error("【hystrix】调用{}异常", "addConceptClass");
        return null;
    }

    @Override
    public RespDTO<List<GetAllForRelationDTO>> searchConceptRuleClass(@Valid SearchConceptVO searchConceptVO) {
        log.error("【hystrix】调用{}异常", "searchConceptRuleClass");
        return null;
    }

    @Override
    public RespDTO<Boolean> clearRuleAll() {
        log.error("【hystrix】调用{}异常", "clearRuleAll");
        return null;
    }

    @Override
    public RespDTO<List<TermConceptDTO>> getTermMatching(@Valid TermMatchingVO termMatchingVO) {
        log.error("【hystrix】调用{}异常", "getTermMatching");
        return null;
    }
}