package com.diagbot.config;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.jwt.crypto.sign.RsaVerifier;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableResourceServer;
import org.springframework.security.oauth2.config.annotation.web.configuration.ResourceServerConfigurerAdapter;
import org.springframework.security.oauth2.config.annotation.web.configurers.ResourceServerSecurityConfigurer;
import org.springframework.security.oauth2.provider.token.store.JwtAccessTokenConverter;
import org.springframework.security.oauth2.provider.token.store.JwtTokenStore;
import org.springframework.util.FileCopyUtils;

import java.io.IOException;

/**
 * @Description: 权限资源配置类
 * @author: gaodm
 * @time: 2018/8/2 14:21
 */
@Configuration
@EnableResourceServer
@ComponentScan({ "com.diagbot.config" })
public class ResourceServerConfigurer extends ResourceServerConfigurerAdapter {
    Logger log = LoggerFactory.getLogger(ResourceServerConfigurer.class);

    @Override
    public void configure(HttpSecurity http) throws Exception {
        http.cors()
                .and()
                .csrf().disable()
                .authorizeRequests()
                .regexMatchers(".*swagger.*", ".*v2.*", ".*webjars.*", "/druid.*", "/actuator.*", "/hystrix.*").permitAll()
                .antMatchers("/sys/user/getJwt").permitAll()
                .antMatchers("/sys/user/refreshJwt").permitAll()
                .antMatchers("/sys/user/checkToken").permitAll()
                //.antMatchers("/sys/user/getUserOrgMenu").permitAll()
                .antMatchers("/oauth/token").permitAll()
                .antMatchers("/oauth/check_token").permitAll()
                .antMatchers("/tran/mappingConfig/exportExcelModule").permitAll()
                .antMatchers("/tran/mappingConfig/dataVerify").permitAll()
                .antMatchers("/tran/mappingConfig/precDataMatch").permitAll()
                .antMatchers("/tran/mappingConfig/precData").permitAll()
                .antMatchers("/tran/mappingConfig/precDataMatch_remote").permitAll()
                .antMatchers("/tran/mappingConfig/importExcelDataVerify").permitAll()
                .antMatchers("/tran/mappingConfig/importExcel").permitAll()
                .antMatchers("/tran/mappingConfig/importExcel_remote").permitAll()
                .antMatchers("/tran/mappingConfig/exportExcel").permitAll()
                .antMatchers("/tran/mappingConfig/exportExcel_remote").permitAll()
                .antMatchers("/tran/mappingConfig/getPage").permitAll()
                .antMatchers("/tran/mappingConfig/getRecord").permitAll()
                .antMatchers("/tran/mappingConfig/getRelatedMapping").permitAll()
                .antMatchers("/tran/mappingConfig/isExistRecord").permitAll()
                .antMatchers("/tran/mappingConfig/saveOrUpdateRecord").permitAll()
                .antMatchers("/tran/mappingConfig/deleteRecord").permitAll()
                .antMatchers("/tran/mappingConfig/deleteRecords").permitAll()
                //.antMatchers("/tran/hospitalInfo/saveRecord").permitAll()
                .antMatchers("/tran/log/pageList").permitAll()
                .antMatchers("/tran/log/getRecordById").permitAll()
                .antMatchers("/tran/hospitalInfo/getHospitalInfo").permitAll()
                .antMatchers("/tran/hospitalInfo/getAllHospitalInfo").permitAll()
                .antMatchers("/tran/hospitalInfo/getAllEnableHospitalInfo").permitAll()
                .antMatchers("/tran/hospitalInfo/getHospitalInfoById").permitAll()
                .antMatchers("/sys/versionInfo/getVersionInfoAlls").permitAll()
                .antMatchers("/sys/disclaimerInfo/getDisclaimerInfo").permitAll()
                .antMatchers("/sys/mr/createMr").permitAll()
                .antMatchers("/sys/mr/getMr").permitAll()
                .antMatchers("/sys/mr/getTcmMr").permitAll()
                .antMatchers("/sys/mr/getIndicationMr").permitAll()
                .antMatchers("/sys/plan/getSysPlanInfoDatas").permitAll()
                .antMatchers("/sys/mrqc/analyze_run").permitAll()
                .antMatchers("/sys/tokenPermission/delPermission").permitAll()
                .antMatchers("/sys/tokenPermission/getPermission").permitAll()
                .antMatchers("/sys/push/push").permitAll()
                .antMatchers("/sys/push/pushApi").permitAll()
                .antMatchers("/sys/push/indicationPush").permitAll()
                .antMatchers("/sys/push/indicationExtPush").permitAll()
                .antMatchers("/sys/push/pushPlan").permitAll()
                .antMatchers("/demo/templateInfo/updateByIdUsNames").permitAll()
                .antMatchers("/demo/templateInfo/saveTemplateInfo").permitAll()
                .antMatchers("/demo/templateInfo/cancelTemplateInfos").permitAll()
                .antMatchers("/demo/templateInfo/getTemplatePageAlls").permitAll()
                .antMatchers("/demo/templateInfo/getTemplatebyId").permitAll()
                .antMatchers("/sys/tokenPermission/getPermission").permitAll()
                //.antMatchers("/sys/plan/getPlanInfoPages").permitAll()
                //.antMatchers("/sys/plan/savePlanInfoDatas").permitAll()
                //.antMatchers("/sys/plan/getSysPlanInfoDatas").permitAll()
                //.antMatchers("/sys/plan/cancelPlanDatas").permitAll()
                //.antMatchers("/sys/plan/revStopPlans").permitAll()
                .antMatchers("/sys/tokenHospital/getTokenHospital").permitAll()
                .antMatchers("/demo/retrieval/index").permitAll()
                .antMatchers("/kl/conceptInfo/staticKnowledgeIndex").permitAll()
                .antMatchers("/kl/conceptInfo/staticKnowledgeIndexWithoutInfo").permitAll()
                .antMatchers("/kl/conceptInfo/getStaticKnowledge").permitAll()
                .antMatchers("/kl/conceptInfo/getStaticKnowledgeForHIS").permitAll()
                .antMatchers("/kl/conceptInfo/isExistForHIS").permitAll()
                .antMatchers("/kl/conceptInfo/getPage").permitAll()
                .antMatchers("/kl/conceptInfo/staticIndexPage").permitAll()
                //.antMatchers("/kl/conceptInfo/saveOrUpdateRecord").permitAll()
                //.antMatchers("/kl/conceptInfo/changeStatus").permitAll()
                .antMatchers("/kl/conceptInfo/isExist").permitAll()
                .antMatchers("/kl/conceptInfo/getRecordById").permitAll()
                .antMatchers("/kl/conceptInfo/updateHasInfoStatusBatch").permitAll()
                .antMatchers("/sys/planDetail/getPlanDetailDatas").permitAll()
                //.antMatchers("/sys/planDetail/savePlanDetails").permitAll()
                //.antMatchers("/sys/planDetail/cancelPlanDetails").permitAll()
                //.antMatchers("/sys/planDetail/revStopPlanDetails").permitAll()
                //.antMatchers("/sys/plan/getDefaultPlans").permitAll()
                .antMatchers("/sys/dictionaryInfo/getList").permitAll()
                .antMatchers("/sys/dictionaryInfo/getListBack").permitAll()
                .antMatchers("/sys/plan/getPlanInfoIds").permitAll()
                .antMatchers("/sys/file/uploadImage").permitAll()
                .antMatchers("/sys/file/deleteRemoteFile").permitAll()
                .antMatchers("/sys/mrqc/caseWritingPrompt").permitAll()
                .antMatchers("/demo/testcaseInfo/testcaseProcess").permitAll()
                .antMatchers("/demo/mrtestInfo/importExcel").permitAll()
                .antMatchers("/demo/mrtestInfo/exportExcel").permitAll()
                .antMatchers("/demo/mrtestInfo/mrTestProcess").permitAll()
                .antMatchers("/kl/dictionary/getDictionarys").permitAll()
                .antMatchers("/klRulePlan/getMenu").permitAll()
                .antMatchers("/klRule/getKlRuleInfoPage").permitAll()
                .antMatchers("/klRule/getByIdRuleInfo").permitAll()
                .antMatchers("/klRule/saveRuleInfo").permitAll()
                .antMatchers("/klRule/clearRuleInfo").permitAll()
                .antMatchers("/klRule/disableRuleInfo").permitAll()
                .antMatchers("/klRule/startRuleInfo").permitAll()
                .antMatchers("/klDisease/searchConcept").permitAll()
                .antMatchers("/klDisease/addConceptClass").permitAll()
                .antMatchers("/klDisease/searchConceptRuleClass").permitAll()
                .antMatchers("/cache/clearRuleAll").permitAll()
                .antMatchers("/term/termMatching").permitAll()
                .antMatchers("/sys/mr/testIndication").permitAll()
                .antMatchers("/test/logTest").permitAll()
                .antMatchers("/dataPage/docking/getDataService").permitAll()
                .antMatchers("/dataPage/docking/getStaticKnowledge").permitAll()
                .antMatchers("/dataPage/docking/getDataEngine").permitAll()
                .antMatchers("/dataPage/docking/addUserAndRole").permitAll()
                .antMatchers("/**").authenticated();
        //                .antMatchers("/**").permitAll();
    }


    @Override
    public void configure(ResourceServerSecurityConfigurer resources) throws Exception {
        log.info("Configuring ResourceServerSecurityConfigurer");
        resources.resourceId("user-service").tokenStore(new JwtTokenStore(jwtTokenEnhancerClient()));
    }

    @Autowired
    private CustomAccessTokenConverter customAccessTokenConverter;

    @Bean("jwtTokenEnhancerClient")
    protected JwtAccessTokenConverter jwtTokenEnhancerClient() {
        JwtAccessTokenConverter converter = new JwtAccessTokenConverter();
        Resource resource = new ClassPathResource("public.cert");
        String publicKey;
        try {
            publicKey = new String(FileCopyUtils.copyToByteArray(resource.getInputStream()));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        converter.setVerifierKey(publicKey);
        //不设置这个会出现 Cannot convert access token to JSON
        converter.setVerifier(new RsaVerifier(publicKey));
        converter.setAccessTokenConverter(customAccessTokenConverter);
        log.info("Created jwtTokenEnhancerClient success");
        return converter;
    }
}
