package com.diagbot.web;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.TcmDTO;
import com.diagbot.facade.MrFacade;
import com.diagbot.facade.PushFacade;
import com.diagbot.util.BeanUtil;
import com.diagbot.vo.IndicationPushVO;
import com.diagbot.vo.MrVO;
import com.diagbot.vo.PushJoinVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * @Description: 病历保存到redis控制层
 * @author: gaodm
 * @time: 2019/8/28 16:25
 */
@RestController
@RequestMapping("/sys/mr")
@Api(value = "电子病历API[by:wangfeng]", tags = { "电子病历API" })
@SuppressWarnings("unchecked")
public class MrController {

	@Autowired
	private MrFacade mrFacade;
	@Autowired
	private PushFacade pushFacade;

	@ApiOperation(value = "保存病历信息:[by:gaodm]",
			notes = "")
	@PostMapping("/createMr")
	@SysLogger("createMr")
	public RespDTO<String> createMr(@RequestBody PushJoinVO pushJoinVO) {
		return RespDTO.onSuc(mrFacade.createMr(pushJoinVO));
	}

	@ApiOperation(value = "获取病历信息 :[by:gaodm]",
			notes = "mrId: 病历编号，必填<br>")
	@PostMapping("/getMr")
	@SysLogger("getMr")
	public RespDTO<PushJoinVO> getMr(@RequestBody @Valid MrVO mrVO) {
		return RespDTO.onSuc(mrFacade.getMr(mrVO.getMrId()));
	}

	@ApiOperation(value = "获取中医病历信息 :[by:zhaops]",
			notes = "mrId: 病历编号，必填<br>")
	@PostMapping("/getTcmMr")
	@SysLogger("getTcmMr")
	public RespDTO<TcmDTO> getTcmMr(@RequestBody @Valid MrVO mrVO) {
		return RespDTO.onSuc(mrFacade.getTcmMr(mrVO.getMrId()));
	}

	@ApiOperation(value = "获取提醒类结果 :[by:zhoutg]",
			notes = "mrId: 病历编号，必填<br>")
	@PostMapping("/getIndicationMr")
	@SysLogger("getIndicationMr")
	public RespDTO<IndicationDTO> getIndicationMr(@RequestBody @Valid MrVO mrVO) {
		return RespDTO.onSuc(mrFacade.getIndicationMr(mrVO));
	}

	@ApiOperation(value = "根据病历编号测试开单 :[by:zhoutg]",
			notes = "mrId: 病历编号，必填<br>")
	@PostMapping("/testIndication")
	@SysLogger("testIndication")
	public RespDTO<IndicationDTO> testIndication(@RequestBody @Valid MrVO mrVO) {
		PushJoinVO pushJoinVO = mrFacade.getMr(mrVO.getMrId());
		IndicationPushVO indicationPushVO = new IndicationPushVO();
		BeanUtil.copyProperties(pushJoinVO, indicationPushVO);
		indicationPushVO.setRuleType("1,2,3,4");
		IndicationDTO indicationDTO = pushFacade.indicationPush(indicationPushVO);
		return RespDTO.onSuc(indicationDTO);
	}
}